==> haskell-executable-path-0.0.3.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
key: executable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
license: LicenseRef-PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
author: Balazs Komuves
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
abi: f6d416917ab9053b64ddb5dc86fd68f6
exposed: True
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-HAUXy7yynGAqn9mH431ik
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-executable-path-0.0.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-executable-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: executable-path
version: 0.0.3.1
id: executable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
key: executable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
license: LicenseRef-PublicDomain
maintainer: bkomuves (plus) hackage (at) gmail (dot) com
author: Balazs Komuves
stability: Experimental
homepage: http://code.haskell.org/~bkomuves/
synopsis: Finding out the full path of the executable.
description:
    The documentation of "System.Environment.getProgName" says that
    \"However, this is hard-to-impossible to implement on some non-Unix OSes,
    so instead, for maximum portability, we just return the leafname
    of the program as invoked.\"
    This library tries to provide the missing path.
    Note: Since base 4.6.0.0, there is also a function
    "System.Environment.getExecutablePath".
category: System
abi: 14ef1cc54f279eced0dbb601759c1e68
exposed: True
exposed-modules:
    System.Environment.Executable
hidden-modules: System.Environment.Executable.Linux
import-dirs: /usr/lib/ghc-8.6.1/site-local/executable-path-0.0.3.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/executable-path-0.0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/executable-path-0.0.3.1
hs-libraries: HSexecutable-path-0.0.3.1-9dmdEZR5Jfi4V3umpMCB9u
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-executable-path/html/executable-path.haddock
haddock-html: /usr/share/doc/haskell-executable-path/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
